Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(173)

Unified Diff: tools/testing/dart/test_runner.dart

Issue 687213002: Retry flaky tests on Safari. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comment. Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/bots/compiler.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/dart/test_runner.dart
diff --git a/tools/testing/dart/test_runner.dart b/tools/testing/dart/test_runner.dart
index 3eb76e35d335d11728d3a3e261c71040dd6f0482..fd2922090313ec6e541fcf8600057fd9ecb81331 100644
--- a/tools/testing/dart/test_runner.dart
+++ b/tools/testing/dart/test_runner.dart
@@ -2605,8 +2605,10 @@ bool shouldRetryCommand(CommandOutput output) {
}
}
- // We currently rerun dartium tests, see issue 14074
- if (command is BrowserTestCommand && command.displayName == 'dartium') {
+ // We currently rerun dartium tests, see issue 14074.
+ // We rerun tests on Safari because 6.2 and 7.1 are flaky. Issue 21434.
+ if (command is BrowserTestCommand &&
+ (command.browser == 'dartium' || command.browser == 'safari')) {
return true;
}
}
« no previous file with comments | « tools/bots/compiler.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698